@@ -27,6 +27,11 @@
 (require 'sendmail)
 (require 'mailcrypt)
 
+(eval-when-compile
+  (autoload 'shuffle-vector "cookie1")
+  (autoload 'expand-mail-aliases "mail-abbrevs"))
+
+
 (eval-and-compile
   (autoload 'mc-cleanup-recipient-headers "mc-toplev")
   (autoload 'mc-encrypt-message "mc-toplev"))
@@ -481,6 +486,9 @@ a description of Levien file format."
 	  (mapconcat 'identity regexps "\\)\\|\\(")
 	  "\\)"))
 
+; Quiet a warning message when the user hasn't set this.
+(defvar gnus-user-from-line nil)
+
 (defun mc-user-mail-address ()
   "Figure out the user's Email address as best we can."
   (mc-strip-address
